"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanHeaders = scanHeaders;
const detectorUtils_1 = require("../utils/functions/detectorUtils");
/**
 * Escanea los encabezados de una solicitud HTTP y busca posibles problemas de seguridad.
 *
 * @param headers - Los encabezados de la solicitud HTTP.
 * @param options - Opciones de escaneo.
 * @returns Un array de cadenas que representan los problemas encontrados en los encabezados.
 *
 * @remarks
 * Esta función recorre los encabezados de la solicitud HTTP y realiza un escaneo de seguridad en las claves y/o valores de los encabezados, según las opciones proporcionadas.
 *
 * @example
 * ```typescript
 * const headers = {
 *   'Content-Type': 'application/json',
 *   'Authorization': 'Bearer token',
 *   'X-Forwarded-For': '192.168.0.1',
 * };
 *
 * const options = {
 *   keys: true,
 *   values: true,
 * };
 *
 * const issues = scanHeaders(headers, options);
 * console.log(issues);
 * Output: ['Authorization header is vulnerable to injection attacks']
 * ```
 *
 * @author Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
function scanHeaders(headers, options) {
    const issues = [];
    const { keys, values } = options;
    Object.entries(headers).forEach(([key, value]) => {
        if (keys) {
            (0, detectorUtils_1.checkDetectors)(key, key, issues, options, true);
        }
        if (values) {
            (0, detectorUtils_1.checkDetectors)(value, key, issues, options);
        }
    });
    return issues;
}
//# sourceMappingURL=scanHeaders.js.map