const COMMAND_INJECTION_PATTERNS = [
  /(&&|\|\|)/,
  /\|/,
  /;/,
  /\$\(.*?\)/,
  /`.*?`/,
  /\b(eval|exec|system|popen|passthru|shell_exec|proc_open)\b/i,
  /\bsh\b/i,
  /\bbash\b/i,
  /\bperl\b/i,
  /\bpython\b/i,
  /\bruby\b/i,
  /\bphp\b/i,
  /\bjava\b/i,
  /\bnode\b/i,
  /\bawk\b/i,
  /\bfind\b/i,
  /\bxargs\b/i,
  /\bwget\b/i,
  /\bcurl\b/i,
  /\bnetcat\b/i,
  /\bnc\b/i,
  /\bftp\b/i,
  /\btftp\b/i,
  /\bsocat\b/i,
  /\b(?:rm|mv|cp|chmod|chown|chgrp)\b/i,
  /\b(?:ps|top|kill|pkill|killall)\b/i,
  /\b(?:ifconfig|ip a|ip addr|ip link|ip route)\b/i,
  /\buname\b/i,
  /\bid\b/i,
  /\bwhoami\b/i,
  /\bhostname\b/i,
  /\bdig\b/i,
  /\bnslookup\b/i,
];

/**
 * Detects if there is a potential command injection vulnerability in a given string.
 *
 * @param input - The string to analyze.
 * @returns `true` if a potential command injection vulnerability is detected, otherwise `false`.
 *
 * @remarks
 * This function uses a series of regular expressions to look for common command injection patterns in the input string.
 * Patterns include shell operators, command substitution, backticks, and common command execution functions.
 *
 * @example
 * ```typescript
 * const input = "ls; cat /etc/passwd";
 * const isCommandInjection = detectCommandInjection(input);
 * console.log(isCommandInjection); // Output: true
 * ```
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export function detectCommandInjection(input: string): boolean {
  return COMMAND_INJECTION_PATTERNS.some((pattern) => pattern.test(input));
}
